@@ -337,7 +337,7 @@ public:
 		unsigned long rate;
 		unsigned long bitrate;
 		unsigned order;
-		unsigned framesize, framecount, headersize;
+		unsigned framesize, framecount, headersize, padding;
 		timeout_t framing;
 		char *annotation;
 
